@@ -14,7 +14,7 @@ from pythonzestclient import pyZestUtil
 import socket as sc
 
 
-from exception.pyZestException import PyZestException
+from pythonzestclient.exception.pyZestException import PyZestException
 
 
 class PyZestClient:
